@@ -21,10 +21,10 @@ import java.util.Optional;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
-import org.kie.workbench.common.dmn.api.definition.v1_1.InformationItem;
-import org.kie.workbench.common.dmn.api.definition.v1_1.List;
-import org.kie.workbench.common.dmn.api.definition.v1_1.LiteralExpression;
-import org.kie.workbench.common.dmn.api.definition.v1_1.Relation;
+import org.kie.workbench.common.dmn.api.definition.model.InformationItem;
+import org.kie.workbench.common.dmn.api.definition.model.List;
+import org.kie.workbench.common.dmn.api.definition.model.LiteralExpression;
+import org.kie.workbench.common.dmn.api.definition.model.Relation;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.relation.RelationColumn;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.relation.RelationUIModelMapper;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.ListSelectorView;
@@ -37,7 +37,7 @@ import org.kie.workbench.common.stunner.core.graph.command.GraphCommandResultBui
 import org.kie.workbench.common.stunner.core.rule.RuleManager;
 import org.kie.workbench.common.stunner.core.rule.RuleViolation;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 import org.uberfire.ext.wires.core.grids.client.model.GridData;
 import org.uberfire.ext.wires.core.grids.client.model.GridRow;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridData;
@@ -46,12 +46,13 @@ import org.uberfire.ext.wires.core.grids.client.widget.grid.columns.RowNumberCol
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertTrue;
+import static org.kie.workbench.common.dmn.client.widgets.grid.model.BaseHasDynamicHeightCell.DEFAULT_HEIGHT;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.reset;
 import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.verify;
 
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(MockitoJUnitRunner.Silent.class)
 public class AddRelationRowCommandTest {
 
     @Mock
@@ -96,7 +97,8 @@ public class AddRelationRowCommandTest {
         this.uiModel.appendColumn(uiRowNumberColumn);
         this.uiModelMapper = new RelationUIModelMapper(() -> uiModel,
                                                        () -> Optional.of(relation),
-                                                       listSelector);
+                                                       listSelector,
+                                                       DEFAULT_HEIGHT);
 
         makeCommand(0);
 
@@ -139,12 +141,12 @@ public class AddRelationRowCommandTest {
                      relation.getColumn().size());
         assertEquals(1,
                      relation.getRow().get(0).getExpression().size());
-        assertTrue(relation.getRow().get(0).getExpression().get(0) instanceof LiteralExpression);
+        assertTrue(relation.getRow().get(0).getExpression().get(0).getExpression() instanceof LiteralExpression);
 
         assertEquals(relation,
                      row.getParent());
         assertEquals(relation.getRow().get(0),
-                     relation.getRow().get(0).getExpression().get(0).getParent());
+                     relation.getRow().get(0).getExpression().get(0).getExpression().getParent());
     }
 
     @Test
@@ -167,12 +169,12 @@ public class AddRelationRowCommandTest {
                      relation.getColumn().size());
         assertEquals(1,
                      relation.getRow().get(1).getExpression().size());
-        assertTrue(relation.getRow().get(1).getExpression().get(0) instanceof LiteralExpression);
+        assertTrue(relation.getRow().get(1).getExpression().get(0).getExpression() instanceof LiteralExpression);
 
         assertEquals(relation,
                      row.getParent());
         assertEquals(relation.getRow().get(1),
-                     relation.getRow().get(1).getExpression().get(0).getParent());
+                     relation.getRow().get(1).getExpression().get(0).getExpression().getParent());
     }
 
     @Test
@@ -305,7 +307,7 @@ public class AddRelationRowCommandTest {
     @Test
     public void testCanvasCommandUndoWithColumns() {
         relation.getColumn().add(new InformationItem());
-        relation.getRow().add(new org.kie.workbench.common.dmn.api.definition.v1_1.List());
+        relation.getRow().add(new org.kie.workbench.common.dmn.api.definition.model.List());
         uiModel.appendColumn(uiModelColumn);
         uiModel.appendRow(new BaseGridRow());
         uiModelMapper.fromDMNModel(0, 0);
