@@ -40,9 +40,9 @@ import org.kie.workbench.common.stunner.core.client.canvas.event.registration.Ca
 import org.kie.workbench.common.stunner.core.client.session.ClientSession;
 import org.kie.workbench.common.stunner.core.graph.Element;
 import org.mockito.Mock;
+import org.mockito.Mockito;
 
 import static org.junit.Assert.assertEquals;
-import static org.mockito.Matchers.anyString;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.spy;
@@ -163,7 +163,7 @@ public class DecisionNavigatorObserverTest {
         observer.init(presenter);
         observer.selectItem(event.getHasExpression());
 
-        verify(treePresenter, never()).selectItem(anyString());
+        verify(treePresenter, never()).selectItem(Mockito.<String>any());
     }
 
     @Test
