@@ -43,6 +43,8 @@ import org.kie.workbench.common.stunner.core.graph.content.view.Connection;
 import org.kie.workbench.common.stunner.core.graph.content.view.ViewConnector;
 
 import static org.kie.workbench.common.stunner.core.client.canvas.controls.keyboard.KeysMatcher.doKeysMatch;
+import static org.kie.workbench.common.stunner.core.client.event.keyboard.KeyboardEvent.Key.C;
+import static org.kie.workbench.common.stunner.core.client.event.keyboard.KeyboardEvent.Key.CONTROL;
 
 /**
  * This session command obtains the selected elements on session and copy the elements to a clipboard.
@@ -96,9 +98,7 @@ public class CopySelectionSessionCommand extends AbstractSelectionAwareSessionCo
     }
 
     private void handleCtrlC(final Key[] keys) {
-        if (doKeysMatch(keys,
-                        Key.CONTROL,
-                        Key.C)) {
+        if (doKeysMatch(keys, CONTROL, C)) {
             this.execute();
         }
     }
