@@ -17,13 +17,14 @@
 package org.kie.workbench.common.stunner.core.client.canvas.controls.select;
 
 import java.util.Collections;
+import java.util.Optional;
 
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
+import org.kie.soup.commons.util.Sets;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvas;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
-import org.kie.workbench.common.stunner.core.client.canvas.Layer;
 import org.kie.workbench.common.stunner.core.client.canvas.event.registration.CanvasShapeRemovedEvent;
 import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasClearSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasSelectionEvent;
@@ -39,25 +40,26 @@ import org.kie.workbench.common.stunner.core.client.shape.view.event.ViewEventTy
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
 import org.kie.workbench.common.stunner.core.diagram.Metadata;
 import org.kie.workbench.common.stunner.core.graph.Element;
-import org.kie.workbench.common.stunner.core.graph.content.view.BoundsImpl;
+import org.kie.workbench.common.stunner.core.graph.content.Bounds;
 import org.kie.workbench.common.stunner.core.graph.content.view.ViewImpl;
+import org.kie.workbench.common.stunner.core.graph.processing.index.Index;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Captor;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 import org.uberfire.mocks.EventSourceMock;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(MockitoJUnitRunner.Silent.class)
 public class MapSelectionControlTest {
 
     private static final String ROOT_UUID = "root-uuid1";
@@ -76,10 +78,10 @@ public class MapSelectionControlTest {
     private AbstractCanvas canvas;
 
     @Mock
-    private Layer layer;
+    private Diagram diagram;
 
     @Mock
-    private Diagram diagram;
+    private Index index;
 
     @Mock
     private Metadata metadata;
@@ -87,9 +89,15 @@ public class MapSelectionControlTest {
     @Mock
     private Object definition;
 
+    @Mock
+    private Object rootDefinition;
+
     @Mock
     private Element element;
 
+    @Mock
+    private Element rootElement;
+
     @Mock
     private Shape<ShapeView> shape;
 
@@ -111,14 +119,18 @@ public class MapSelectionControlTest {
     public void setup() throws Exception {
         ShapeViewExtStub shapeView = new ShapeViewExtStub(shapeEventHandler,
                                                           hasControlPoints);
+        when(rootElement.getUUID()).thenReturn(ROOT_UUID);
+        when(rootElement.getContent()).thenReturn(new ViewImpl<>(rootDefinition,
+                                                                 Bounds.create(0, 0, 10, 10)));
         when(element.getUUID()).thenReturn(ELEMENT_UUID);
         when(element.getContent()).thenReturn(new ViewImpl<>(definition,
-                                                             BoundsImpl.build(0, 0, 10, 10)));
+                                                             Bounds.create(0, 0, 10, 10)));
         when(canvasHandler.getDiagram()).thenReturn(diagram);
         when(diagram.getMetadata()).thenReturn(metadata);
         when(metadata.getCanvasRootUUID()).thenReturn(ROOT_UUID);
         when(canvasHandler.getCanvas()).thenReturn(canvas);
-        when(canvas.getLayer()).thenReturn(layer);
+        when(canvasHandler.getAbstractCanvas()).thenReturn(canvas);
+        when(canvasHandler.getGraphIndex()).thenReturn(index);
         when(canvas.getShape(eq(ELEMENT_UUID))).thenReturn(shape);
         when(canvas.getShapes()).thenReturn(Collections.singletonList(shape));
         when(shape.getUUID()).thenReturn(ELEMENT_UUID);
@@ -132,7 +144,7 @@ public class MapSelectionControlTest {
     @Test
     public void testEnable() {
         tested.init(canvasHandler);
-        verify(layer,
+        verify(canvas,
                times(1)).addHandler(eq(ViewEventType.MOUSE_CLICK),
                                     any(MouseClickHandler.class));
     }
@@ -142,7 +154,7 @@ public class MapSelectionControlTest {
         tested.init(canvasHandler);
         final ArgumentCaptor<MouseClickHandler> clickHandlerArgumentCaptor =
                 ArgumentCaptor.forClass(MouseClickHandler.class);
-        verify(layer,
+        verify(canvas,
                times(1)).addHandler(eq(ViewEventType.MOUSE_CLICK),
                                     clickHandlerArgumentCaptor.capture());
         final MouseClickHandler clickHandler = clickHandlerArgumentCaptor.getValue();
@@ -170,7 +182,7 @@ public class MapSelectionControlTest {
         tested.init(canvasHandler);
         final ArgumentCaptor<MouseClickHandler> clickHandlerArgumentCaptor =
                 ArgumentCaptor.forClass(MouseClickHandler.class);
-        verify(layer,
+        verify(canvas,
                times(1)).addHandler(eq(ViewEventType.MOUSE_CLICK),
                                     clickHandlerArgumentCaptor.capture());
         final MouseClickHandler clickHandler = clickHandlerArgumentCaptor.getValue();
@@ -208,13 +220,14 @@ public class MapSelectionControlTest {
     public void testSelect() {
         tested.init(canvasHandler);
         tested.register(element);
-        tested.select(element);
+        tested.select(element.getUUID());
         assertEquals(1, tested.getSelectedItems().size());
         assertEquals(ELEMENT_UUID, tested.getSelectedItems().iterator().next());
         verify(shape, times(1)).applyState(eq(ShapeState.SELECTED));
         verify(shape, never()).applyState(eq(ShapeState.NONE));
         verify(shape, never()).applyState(eq(ShapeState.INVALID));
         verify(shape, never()).applyState(eq(ShapeState.HIGHLIGHT));
+        verify(canvas, times(1)).focus();
         final ArgumentCaptor<CanvasSelectionEvent> elementSelectedEventArgumentCaptor =
                 ArgumentCaptor.forClass(CanvasSelectionEvent.class);
         verify(elementSelectedEvent,
@@ -224,24 +237,49 @@ public class MapSelectionControlTest {
         assertEquals(ELEMENT_UUID, event.getIdentifiers().iterator().next());
     }
 
+    @Test
+    public void testSelectOnlyOnce() {
+        tested.init(canvasHandler);
+        tested.register(element);
+        tested.select(element.getUUID());
+        tested.select(element.getUUID());
+
+        assertEquals(1, tested.getSelectedItems().size());
+        assertEquals(ELEMENT_UUID, tested.getSelectedItems().iterator().next());
+        verify(shape, times(2)).applyState(eq(ShapeState.SELECTED));
+        verify(shape, never()).applyState(eq(ShapeState.NONE));
+        verify(shape, never()).applyState(eq(ShapeState.INVALID));
+        verify(shape, never()).applyState(eq(ShapeState.HIGHLIGHT));
+        verify(canvas, times(2)).focus();
+        final ArgumentCaptor<CanvasSelectionEvent> elementSelectedEventArgumentCaptor =
+                ArgumentCaptor.forClass(CanvasSelectionEvent.class);
+        // Verify it has only been fired once
+        verify(elementSelectedEvent,
+               times(2)).fire(elementSelectedEventArgumentCaptor.capture());
+        final CanvasSelectionEvent event = elementSelectedEventArgumentCaptor.getValue();
+        assertEquals(1, event.getIdentifiers().size());
+        assertEquals(ELEMENT_UUID, event.getIdentifiers().iterator().next());
+    }
+
     @Test
     public void testSelectReadOnly() {
         tested.init(canvasHandler);
         tested.register(element);
         tested.setReadonly(true);
-        tested.select(element);
+        tested.select(element.getUUID());
         verify(shape, never()).applyState(eq(ShapeState.SELECTED));
         verify(shape, never()).applyState(eq(ShapeState.NONE));
         verify(shape, never()).applyState(eq(ShapeState.INVALID));
         verify(shape, times(1)).applyState(eq(ShapeState.HIGHLIGHT));
+        verify(canvas, times(1)).focus();
     }
 
     @Test
     public void testDeselect() {
         tested.init(canvasHandler);
         tested.register(element);
-        tested.select(element);
-        tested.deselect(element);
+        tested.select(element.getUUID());
+        tested.deselect(element.getUUID());
         assertTrue(tested.getSelectedItems().isEmpty());
         verify(shape, times(1)).applyState(eq(ShapeState.SELECTED));
         verify(shape, times(1)).applyState(eq(ShapeState.NONE));
@@ -253,7 +291,7 @@ public class MapSelectionControlTest {
     public void testClearSelection() {
         tested.init(canvasHandler);
         tested.register(element);
-        tested.select(element);
+        tested.select(element.getUUID());
         tested.clearSelection();
         assertTrue(tested.getSelectedItems().isEmpty());
         verify(shape, times(1)).applyState(eq(ShapeState.SELECTED));
@@ -264,11 +302,60 @@ public class MapSelectionControlTest {
                times(1)).fire(any(CanvasClearSelectionEvent.class));
     }
 
+    @Test
+    public void testGetSelectedItemDefinitionWithNoItemsSelected() {
+        tested.init(canvasHandler);
+
+        when(index.get(ROOT_UUID)).thenReturn(rootElement);
+
+        final Optional<Object> selectedItemDefinition = tested.getSelectedItemDefinition();
+        assertTrue(selectedItemDefinition.isPresent());
+        assertEquals(rootElement, selectedItemDefinition.get());
+    }
+
+    @Test
+    public void testGetSelectedItemDefinitionWithNoItemsSelectedAndNoDiagram() {
+        tested.init(canvasHandler);
+
+        when(canvasHandler.getDiagram()).thenReturn(null);
+
+        final Optional<Object> selectedItemDefinition = tested.getSelectedItemDefinition();
+        assertFalse(selectedItemDefinition.isPresent());
+    }
+
+    @Test
+    public void testGetSelectedItemDefinitionWithOneItemSelected() {
+        tested.init(canvasHandler);
+        tested.register(element);
+        tested.select(element.getUUID());
+
+        when(index.get(ELEMENT_UUID)).thenReturn(element);
+
+        final Optional<Object> selectedItemDefinition = tested.getSelectedItemDefinition();
+        assertTrue(selectedItemDefinition.isPresent());
+        assertEquals(element, selectedItemDefinition.get());
+    }
+
+    @Test
+    public void testGetSelectedItemDefinitionWithMultipleItemsSelected() {
+        tested.init(canvasHandler);
+        tested.register(element);
+        tested.register(rootElement);
+        tested.select(new Sets.Builder<String>().add(ROOT_UUID).add(ELEMENT_UUID).build());
+
+        when(index.get(ELEMENT_UUID)).thenReturn(element);
+        when(index.get(ROOT_UUID)).thenReturn(rootElement);
+
+        final Optional<Object> selectedItemDefinition = tested.getSelectedItemDefinition();
+        assertTrue(selectedItemDefinition.isPresent());
+        assertEquals(rootElement, selectedItemDefinition.get());
+    }
+
     @Test
     public void testOnShapeRemovedEvent() {
         tested.init(canvasHandler);
         tested.register(element);
-        tested.select(element);
+        tested.select(element.getUUID());
         CanvasShapeRemovedEvent shapeRemovedEvent = new CanvasShapeRemovedEvent(canvas,
                                                                                 shape);
         tested.onShapeRemoved(shapeRemovedEvent);
@@ -280,7 +367,7 @@ public class MapSelectionControlTest {
     public void testOnClearSelectionEvent() {
         tested.init(canvasHandler);
         tested.register(element);
-        tested.select(element);
+        tested.select(element.getUUID());
         CanvasClearSelectionEvent event = new CanvasClearSelectionEvent(canvasHandler);
         tested.onCanvasClearSelection(event);
         assertTrue(tested.getSelectedItems().isEmpty());
@@ -318,7 +405,7 @@ public class MapSelectionControlTest {
     public void testClear() {
         tested.init(canvasHandler);
         tested.register(element);
-        tested.select(element);
+        tested.select(element.getUUID());
         tested.clear();
         assertTrue(tested.getSelectedItems().isEmpty());
         verify(clearSelectionEvent,
@@ -331,7 +418,8 @@ public class MapSelectionControlTest {
     public void testDestroy() {
         tested.init(canvasHandler);
         tested.destroy();
-        verify(layer).removeHandler(any(MouseClickHandler.class));
+        assertFalse(tested.getSelectedItemDefinition().isPresent());
+        verify(canvas).removeHandler(any(MouseClickHandler.class));
     }
 
     private boolean isRegistered(Element e) {
