@@ -24,18 +24,18 @@ import org.kie.workbench.common.stunner.core.rule.RuleViolations;
 import org.kie.workbench.common.stunner.core.rule.ext.RuleExtension;
 import org.kie.workbench.common.stunner.core.rule.ext.RuleExtensionMultiHandler;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertTrue;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(MockitoJUnitRunner.Silent.class)
 public class ConnectorParentsMatchHandlerTest {
 
     @Mock
@@ -80,25 +80,7 @@ public class ConnectorParentsMatchHandlerTest {
                      tested.getContextType());
     }
 
-    @Test(expected = IllegalArgumentException.class)
-    public void testAcceptNoParentType() {
-        final RuleExtension ruleExtension = mock(RuleExtension.class);
-        when(ruleExtension.getArguments()).thenReturn(new String[]{});
-        final RuleEvaluationContext context = mock(RuleEvaluationContext.class);
-        tested.accepts(ruleExtension,
-                       context);
-    }
-
-    @Test(expected = IllegalArgumentException.class)
-    public void testEvaluateNoParentType() {
-        final RuleExtension ruleExtension = mock(RuleExtension.class);
-        when(ruleExtension.getArguments()).thenReturn(new String[]{});
-        final RuleEvaluationContext context = mock(RuleEvaluationContext.class);
-        tested.evaluate(ruleExtension,
-                        context);
-    }
-
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testAccept() {
         final RuleExtension ruleExtension = mock(RuleExtension.class);
         when(ruleExtension.getArguments()).thenReturn(new String[]{"parentType"});
@@ -110,7 +92,7 @@ public class ConnectorParentsMatchHandlerTest {
                                  eq(context));
     }
 
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testEvaluate() {
         final RuleExtension ruleExtension = mock(RuleExtension.class);
         when(ruleExtension.getArguments()).thenReturn(new String[]{"parentType"});
